/* Copyright John-Philip "Seriema" Johansson (seriema@users.sourceforge.net)
 * released under the MIT license */
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

namespace ThumbViewConnector
{
	/// <summary>
	/// Displays a thumbnail generated with ThumbView.
	/// </summary>
	public class Viewer : System.Windows.Forms.Form
	{
		private System.Windows.Forms.PictureBox pictureBox;
		private System.Windows.Forms.OpenFileDialog openFileDialog;
		private System.Windows.Forms.Button browseButton;

		private System.Windows.Forms.GroupBox extractorInfoGroupBox;
		private System.Windows.Forms.Label extractorVersionLabel;
		private System.Windows.Forms.Label extractorNameLabel;
		private System.Windows.Forms.Label extractorSupportedFiletypesLabel;

		private System.Windows.Forms.GroupBox imageInfoGroupBox;
		private System.Windows.Forms.Label imageInfoLabel;
		private System.Windows.Forms.Label imageBoxLabel;

		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public Viewer()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			//
			// Constructor code after InitializeComponent call
			//

			extractorNameLabel.Text = "Name: " + ExtractorConnector.Name;

			extractorVersionLabel.Text = "Version: " + ExtractorConnector.Version;

			// Use the ThumbView Extractor to set up a filter of supported imagetypes.
			// This could be done in the constructor, but I choose to have it here so all
			// example code is in the same place.
			string[] supportedFiletypes = ExtractorConnector.SupportedFiletypes;
			string filter = string.Empty;
			foreach( string filetype in supportedFiletypes )
				filter += "*." + filetype + "; ";
			filter = filter.Substring(0, filter.Length-2); // Remove the last "; "
			openFileDialog.Filter = "Image Files (" + filter + ") | " + filter;

			extractorSupportedFiletypesLabel.Text = "Files: " + filter;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(Viewer));
			this.pictureBox = new System.Windows.Forms.PictureBox();
			this.browseButton = new System.Windows.Forms.Button();
			this.openFileDialog = new System.Windows.Forms.OpenFileDialog();
			this.imageInfoGroupBox = new System.Windows.Forms.GroupBox();
			this.imageInfoLabel = new System.Windows.Forms.Label();
			this.extractorInfoGroupBox = new System.Windows.Forms.GroupBox();
			this.extractorVersionLabel = new System.Windows.Forms.Label();
			this.extractorNameLabel = new System.Windows.Forms.Label();
			this.extractorSupportedFiletypesLabel = new System.Windows.Forms.Label();
			this.imageBoxLabel = new System.Windows.Forms.Label();
			this.imageInfoGroupBox.SuspendLayout();
			this.extractorInfoGroupBox.SuspendLayout();
			this.SuspendLayout();
			// 
			// pictureBox
			// 
			this.pictureBox.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.pictureBox.Location = new System.Drawing.Point(16, 16);
			this.pictureBox.Name = "pictureBox";
			this.pictureBox.Size = new System.Drawing.Size(200, 200);
			this.pictureBox.TabIndex = 0;
			this.pictureBox.TabStop = false;
			// 
			// browseButton
			// 
			this.browseButton.Location = new System.Drawing.Point(336, 208);
			this.browseButton.Name = "browseButton";
			this.browseButton.Size = new System.Drawing.Size(104, 32);
			this.browseButton.TabIndex = 1;
			this.browseButton.Text = "Open image";
			this.browseButton.Click += new System.EventHandler(this.browseBtn_Click);
			// 
			// openFileDialog
			// 
			this.openFileDialog.Filter = "Image Files (*.tga; *.pcx; *.dds) | *.tga; *.pcx; *.dds";
			// 
			// imageInfoGroupBox
			// 
			this.imageInfoGroupBox.Controls.Add(this.imageInfoLabel);
			this.imageInfoGroupBox.Location = new System.Drawing.Point(240, 152);
			this.imageInfoGroupBox.Name = "imageInfoGroupBox";
			this.imageInfoGroupBox.Size = new System.Drawing.Size(200, 48);
			this.imageInfoGroupBox.TabIndex = 6;
			this.imageInfoGroupBox.TabStop = false;
			this.imageInfoGroupBox.Text = "Image info";
			// 
			// imageInfoLabel
			// 
			this.imageInfoLabel.Location = new System.Drawing.Point(8, 24);
			this.imageInfoLabel.Name = "imageInfoLabel";
			this.imageInfoLabel.Size = new System.Drawing.Size(184, 16);
			this.imageInfoLabel.TabIndex = 5;
			this.imageInfoLabel.Text = "(dimension) (BPP)";
			// 
			// extractorInfoGroupBox
			// 
			this.extractorInfoGroupBox.Controls.Add(this.extractorSupportedFiletypesLabel);
			this.extractorInfoGroupBox.Controls.Add(this.extractorVersionLabel);
			this.extractorInfoGroupBox.Controls.Add(this.extractorNameLabel);
			this.extractorInfoGroupBox.Location = new System.Drawing.Point(240, 16);
			this.extractorInfoGroupBox.Name = "extractorInfoGroupBox";
			this.extractorInfoGroupBox.Size = new System.Drawing.Size(200, 128);
			this.extractorInfoGroupBox.TabIndex = 7;
			this.extractorInfoGroupBox.TabStop = false;
			this.extractorInfoGroupBox.Text = "Extractor info";
			// 
			// extractorVersionLabel
			// 
			this.extractorVersionLabel.Location = new System.Drawing.Point(8, 40);
			this.extractorVersionLabel.Name = "extractorVersionLabel";
			this.extractorVersionLabel.Size = new System.Drawing.Size(184, 16);
			this.extractorVersionLabel.TabIndex = 6;
			this.extractorVersionLabel.Text = "(version)";
			// 
			// extractorNameLabel
			// 
			this.extractorNameLabel.Location = new System.Drawing.Point(8, 24);
			this.extractorNameLabel.Name = "extractorNameLabel";
			this.extractorNameLabel.Size = new System.Drawing.Size(184, 16);
			this.extractorNameLabel.TabIndex = 5;
			this.extractorNameLabel.Text = "(name)";
			// 
			// extractorSupportedFiletypesLabel
			// 
			this.extractorSupportedFiletypesLabel.Location = new System.Drawing.Point(8, 56);
			this.extractorSupportedFiletypesLabel.Name = "extractorSupportedFiletypesLabel";
			this.extractorSupportedFiletypesLabel.Size = new System.Drawing.Size(184, 64);
			this.extractorSupportedFiletypesLabel.TabIndex = 7;
			this.extractorSupportedFiletypesLabel.Text = "(supported filetypes)";
			// 
			// imageBoxLabel
			// 
			this.imageBoxLabel.Location = new System.Drawing.Point(16, 224);
			this.imageBoxLabel.Name = "imageBoxLabel";
			this.imageBoxLabel.Size = new System.Drawing.Size(200, 16);
			this.imageBoxLabel.TabIndex = 8;
			this.imageBoxLabel.Text = "[ 200x200 thumbnail ]";
			this.imageBoxLabel.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// Viewer
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(456, 254);
			this.Controls.Add(this.imageBoxLabel);
			this.Controls.Add(this.extractorInfoGroupBox);
			this.Controls.Add(this.imageInfoGroupBox);
			this.Controls.Add(this.browseButton);
			this.Controls.Add(this.pictureBox);
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.Name = "Viewer";
			this.Text = "ThumbnailViewer";
			this.imageInfoGroupBox.ResumeLayout(false);
			this.extractorInfoGroupBox.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Viewer());
		}


		/// <summary>
		/// Browses for a image file, passing that to ThumbView to generate a
		/// thumbnail and passes it to the picture box.
		/// </summary>
		private void browseBtn_Click(object sender, System.EventArgs e)
		{
			if( openFileDialog.ShowDialog() == DialogResult.OK )
			{
				// Use the ThumbView Extractor to extract a thumbnail.
				System.Drawing.Size requiredSize = pictureBox.Size; // So it can be passed as a ref.
				pictureBox.Image = ExtractorConnector.ExtractThumbnail( openFileDialog.FileName, ExtractorConnector.PixelFormat.RGBA32, ref requiredSize );

				if( pictureBox.Image == null )
				{
					System.Windows.Forms.MessageBox.Show(this, "Image loading failed", "Error");
					return;
				}

				// Use the ThumbView Extractor to get some info on the image.
				System.Drawing.Size originalImageSize;
				ExtractorConnector.PixelFormat originalImageBPP;
				ExtractorConnector.GetInfo( openFileDialog.FileName, out originalImageBPP, out originalImageSize );

				imageInfoLabel.Text = "W: " + originalImageSize.Width + " H: " + originalImageSize.Height + " BPP: " + originalImageBPP;
			}
		}
	}
}
